@@ -1,4 +1,5 @@
 # Data setup
+set.seed(32)
 sim <- stats::arima.sim(list(order = c(1, 0, 0), ar = 0.5),
                         n = 100, innov = rnorm(100))
 
@@ -34,12 +35,26 @@ test_that("plot.nppi handles missing JAB point values", {
   result <- list(jab_point_values = NULL)
   class(result) <- "nppi"
 
-  expect_error(plot.nppi(result), "Error: No valid JAB variance estimates available for plotting.")
+  expect_error(plot.nppi(result), "Error: No valid JAB point values available for plotting.")
 })
 
 test_that("plot.nppi handles all NA JAB point values", {
   result <- list(jab_point_values = rep(NA, 10))
   class(result) <- "nppi"
 
-  expect_error(plot.nppi(result), "Error: No valid JAB variance estimates available for plotting.")
+  expect_error(plot.nppi(result), "Error: No valid JAB point values available for plotting.")
+})
+
+test_that("plot.nppi handles missing JAB pseudo values", {
+  result <- list(jab_point_values = rep(1, 10), jab_pseudo_values = NULL)
+  class(result) <- "nppi"
+
+  expect_error(plot.nppi(result), "Error: No valid JAB pseudo values available for plotting.")
+})
+
+test_that("plot.nppi handles all NA JAB pseudo values", {
+  result <- list(jab_point_values = rep(1, 10), jab_pseudo_values = rep(NA, 10))
+  class(result) <- "nppi"
+
+  expect_error(plot.nppi(result), "Error: No valid JAB pseudo values available for plotting.")
 })
